@@ -84,8 +84,10 @@ int test_common_init(void)
 
 	ranap_set_log_area(DRANAP);
 
-	log_set_print_filename(osmo_stderr_target, 0);
+	log_set_print_filename2(osmo_stderr_target, LOG_FILENAME_NONE);
 	log_set_use_color(osmo_stderr_target, 0);
+	log_set_print_category(osmo_stderr_target, 0);
+	log_set_print_category_hex(osmo_stderr_target, 0);
 	return rc;
 }
 
